pub struct ParserIn<'a> {
pub whole_file: &'a [u8],
pub remaining: &'a [u8],
}Fields
whole_file: &'a [u8]remaining: &'a [u8]Trait Implementations
Sourceimpl<'a> ParseError<ParserIn<'a>> for Error<&[u8]>
impl<'a> ParseError<ParserIn<'a>> for Error<&[u8]>
Sourcefn append(_input: ParserIn<'a>, _kind: ErrorKind, other: Self) -> Self
fn append(_input: ParserIn<'a>, _kind: ErrorKind, other: Self) -> Self
Combines an existing error with a new one created from the input
position and an ErrorKind. This is useful when backtracking
through a parse tree, accumulating error context on the way
Sourcefn from_error_kind(_input: ParserIn<'a>, kind: ErrorKind) -> Self
fn from_error_kind(_input: ParserIn<'a>, kind: ErrorKind) -> Self
Creates an error from the input position and an ErrorKind
impl<'a> Copy for ParserIn<'a>
impl<'a> StructuralPartialEq for ParserIn<'a>